First batch of removal of the headers needed for revision-functions.php
[mailer.git] / css.php
diff --git a/css.php b/css.php
index 3c0e236a26501f69130a077071a08990860ddea9..08ae246a690d4e71f45e974e29042e03c6bc7778 100644 (file)
--- a/css.php
+++ b/css.php
@@ -16,8 +16,8 @@
  * $Author::                                                          $ *
  * -------------------------------------------------------------------- *
  * Copyright (c) 2003 - 2009 by Roland Haeder                           *
- * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
- * For more information visit: http://www.mxchange.org                  *
+ * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
+ * For more information visit: http://mxchange.org                      *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
 require('inc/libs/security_functions.php');
 
 // Footer is disabled in CSS mode
-$GLOBALS['footer_sent'] = -1;
+$GLOBALS['__footer_sent'] = -1;
 
-// This is a CSS file loader!
-$GLOBALS['output_mode'] = 1;
-$GLOBALS['module'] = 'css';
+// Init start time
+$GLOBALS['__start_time'] = microtime(TRUE);
+
+// This is a CSS file loader
+$GLOBALS['__module']      = 'css';
+$GLOBALS['__output_mode'] = 1;
 
 // Load the required file(s)
 require('inc/config-global.php');